o susy é chato
--------------

Comparar as saídas dos testes abertos é tão laborioso que ninguém deveria fazer.
Então não faça.

instalação
----------

Os passos abaixo só funcionarão se você tiver o python configurado nas suas váriaveis de ambiente (algo que você definitivamente deveria fazer).

Se não tiver, use esse `tutorial <https://python.org.br/instalacao-windows/>`_.

Abre teu terminal/prompt de cmd, e digita ``pip install suzo``, e é isso ai.
